const assert = require("assert")
const path = require("path")

if (process.platform == "win32")
	var bp = require("C:/Program Files/Actian/Zen/bin/btrieveJavascript")
else
	var bp = require("/usr/local/actianzen/lib64/btrieveJavascript")

min_x = 0
max_x = 255
btrieveFileName = "squaresAndSquareRoots.btr"
recordLength = 7

if (process.argv.length != 3)
{
   console.log("Usage:", path.basename(process.argv[1]), "uint8_value")
   process.exit(1)
}

integerValue = parseInt(process.argv[2])

if ((integerValue < min_x) || (integerValue > max_x))
{
   console.log("Usage:", path.basename(process.argv[1]), "uint8_value")
   process.exit(1)
}

btrieveClient = new bp.BtrieveClient()
assert(btrieveClient != null)

btrieveKeySegment = new bp.BtrieveKeySegment()
assert(btrieveKeySegment != null)

rc = btrieveKeySegment.SetField(0, 1, bp.Btrieve.DATA_TYPE_UNSIGNED_BINARY)
assert(rc == bp.Btrieve.STATUS_CODE_NO_ERROR, "Error: BtrieveKeySegment.SetField():" + rc + ":" + bp.Btrieve.StatusCodeToString(rc))

btrieveIndexAttributes = new bp.BtrieveIndexAttributes()
assert(btrieveIndexAttributes != null)

rc = btrieveIndexAttributes.AddKeySegment(btrieveKeySegment)
assert(rc == bp.Btrieve.STATUS_CODE_NO_ERROR, "Error: BtrieveIndexAttributes.AddKeySegment():" + rc + ":" + bp.Btrieve.StatusCodeToString(rc))

btrieveFileAttributes = new bp.BtrieveFileAttributes()
assert(btrieveFileAttributes != null)

rc = btrieveFileAttributes.SetFixedRecordLength(recordLength)
assert(rc == bp.Btrieve.STATUS_CODE_NO_ERROR, "Error: BtrieveFileAttributes.SetFixedRecordLength():" + rc + ":" + bp.Btrieve.StatusCodeToString(rc))

rc = btrieveClient.FileCreate(btrieveFileAttributes, btrieveIndexAttributes, btrieveFileName, bp.Btrieve.CREATE_MODE_OVERWRITE)
assert(rc == bp.Btrieve.STATUS_CODE_NO_ERROR, "Error: BtrieveClient.FileCreate():" + rc + ":" + bp.Btrieve.StatusCodeToString(rc))

btrieveFile = new bp.BtrieveFile()
assert(btrieveFile != null)

rc = btrieveClient.FileOpen(btrieveFile, btrieveFileName, "", bp.Btrieve.OPEN_MODE_NORMAL)
assert(rc == bp.Btrieve.STATUS_CODE_NO_ERROR, "Error: BtrieveClient.FileOpen():" + rc + ":" + bp.Btrieve.StatusCodeToString(rc))

// For all the values of x.
for (i = min_x; i <= max_x; i++)
{
    record = new Buffer.alloc(recordLength)
    record.writeUInt8(i, 0)
    record.writeUInt16LE(i * i, 1)
    record.writeFloatLE(Math.sqrt(i), 3)
   
    rc = btrieveFile.RecordCreate(record.buffer)
    assert(rc == bp.Btrieve.STATUS_CODE_NO_ERROR, "Error: BtrieveFile.RecordCreate():" + rc + ":" + bp.Btrieve.StatusCodeToString(rc))
}

record = new Buffer.alloc(recordLength)
key = new Buffer.alloc(1)
key.writeUInt8(integerValue, 0)

rc = btrieveFile.RecordRetrieve(bp.Btrieve.COMPARISON_EQUAL, bp.Btrieve.INDEX_1, key.buffer, record.buffer)
assert(rc == recordLength, "Error: BtrieveFile.RecordRetrieve():" + rc + ":" + bp.Btrieve.StatusCodeToString(btrieveFile.GetLastStatusCode()))

// Print record.
i = record.readUInt8(0)
iSquared = record.readUInt16LE(1)
iSquareRoot = record.readFloatLE(3)
console.log("record: (" + i + ",", iSquared + ",", iSquareRoot + ")")

rc = btrieveClient.FileClose(btrieveFile)
assert(rc == bp.Btrieve.STATUS_CODE_NO_ERROR, "Error: BtrieveClient.FileClose():" + rc + ":" + bp.Btrieve.StatusCodeToString(rc))

rc = btrieveClient.FileDelete(btrieveFileName)
assert(rc == bp.Btrieve.STATUS_CODE_NO_ERROR, "Error: BtrieveClient.FileDelete():" + rc + ":" + bp.Btrieve.StatusCodeToString(rc))
